window.Gleam.initSearch([{"doc":"node_socket_client","title":"node_socket_client","content":"# node_socket_client\n\nBindings to Node&#39;s TCP socket client.\n\n[![Package Version](https://img.shields.io/hexpm/v/node_socket_client)](https://hex.pm/packages/node_socket_client)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/node_socket_client/)\n\n```sh\ngleam add node_socket_client@1\n```\n```gleam\nimport node_socket_client.{DataEvent, CloseEvent, ErrorEvent} as socket\n\npub fn main() {\n  socket.connect(&quot;localhost&quot;, 3000, 0, fn(count, _socket, event) {\n    case event {\n      DataEvent(data) -&gt; io.println(&quot;Got data: &quot; &lt;&gt; data)\n      ErrorEvent(error) -&gt; io.println(&quot;Got error: &quot; &lt;&gt; error)\n      CloseEvent(had_error: True) -&gt; io.println(&quot;Closed with error&quot;)\n      CloseEvent(had_error: False) -&gt; io.println(&quot;Closed&quot;)\n      _other_event -&gt; Nil\n    }\n    count + 1\n  })\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/node_socket_client&gt;.\n","url":"index.html"},{"doc":"node_socket_client","title":"ConnectionFamily","content":"pub type ConnectionFamily {\n  Ipv6\n  Ipv4\n}\n\nIpv6\n\n\nIpv4\n\n\nSynonyms:\nnode_socket_client.ConnectionFamily\nnode_socket_client ConnectionFamily","url":"node_socket_client.html#ConnectionFamily"},{"doc":"node_socket_client","title":"Event","content":"pub type Event(data) {\n  CloseEvent(had_error: Bool)\n  ConnectEvent\n  ConnectionAttemptEvent(\n    ip: String,\n    port: Int,\n    family: ConnectionFamily,\n  )\n  ConnectionAttemptFailedEvent(\n    ip: String,\n    port: Int,\n    family: ConnectionFamily,\n    error: String,\n  )\n  ConnectionAttemptTimeoutEvent(\n    ip: String,\n    port: Int,\n    family: ConnectionFamily,\n  )\n  DataEvent(data: data)\n  DrainEvent\n  EndEvent\n  ErrorEvent(error: String)\n  LookupEvent(\n    result: Result(Nil, String),\n    address: String,\n    family: Option(ConnectionFamily),\n    host: String,\n  )\n  ReadyEvent\n  TimeoutEvent\n}\n\nCloseEvent(had_error: Bool)\n Emitted once the socket is fully closed.Bool\n\n The argument `had_error` is a bool which says if the socket was closed\n due to a transmission error.\n\n https://nodejs.org/api/net.html#event-close_1\n\nConnectEvent\n Emitted when a socket connection is successfully established.\n\n https://nodejs.org/api/net.html#event-connect\n\nConnectionAttemptEvent(\n  ip: String,\n  port: Int,\n  family: ConnectionFamily,\n)\n Emitted when a new connection attempt is started. This may be emitted\n multiple times if the family autoselection algorithm is enabled.\n\n https://nodejs.org/api/net.html#event-connectionattempt\n\nConnectionAttemptFailedEvent(\n  ip: String,\n  port: Int,\n  family: ConnectionFamily,\n  error: String,\n)\n Emitted when a connection attempt failed. This may be emitted multiple\n times if the family autoselection algorithm is enabled.\n\n https://nodejs.org/api/net.html#event-connectionattemptfailed\n\nConnectionAttemptTimeoutEvent(\n  ip: String,\n  port: Int,\n  family: ConnectionFamily,\n)\n Emitted when a connection attempt timed out. This is only emitted (and\n may be emitted multiple times) if the family autoselection algorithm is\n enabled.\n\n https://nodejs.org/api/net.html#event-connectionattempttimeout\n\nDataEvent(data: data)\n Emitted when data is received.\n\n https://nodejs.org/api/net.html#event-data\n\nDrainEvent\n Emitted when the write buffer becomes empty. Can be used to throttle uploads.\n\n https://nodejs.org/api/net.html#event-drain\n\nEndEvent\n Emitted when the other end of the socket signals the end of transmission,\n thus ending the readable side of the socket.\n\n https://nodejs.org/api/net.html#event-end\n\nErrorEvent(error: String)\n Emitted when an error occurs. The &#39;close&#39; event will be called directly\n following this event.\n\n https://nodejs.org/api/net.html#event-error_1\n\nLookupEvent(\n  result: Result(Nil, String),\n  address: String,\n  family: Option(ConnectionFamily),\n  host: String,\n)\n Emitted when an error occurs. The &#39;close&#39; event will be called directly\n following this event.\n\n https://nodejs.org/api/net.html#event-lookup\n\nReadyEvent\n Emitted when a socket is ready to be used.\n\n Triggered immediately after &#39;connect&#39;.\n\n https://nodejs.org/api/net.html#event-ready\n\nTimeoutEvent\n Emitted if the socket times out from inactivity. This is only to notify\n that the socket has been idle. The user must manually close the connection.\n\n https://nodejs.org/api/net.html#event-timeout\n\nSynonyms:\nnode_socket_client.Event\nnode_socket_client Event","url":"node_socket_client.html#Event"},{"doc":"node_socket_client","title":"SocketClient","content":"pub type SocketClient\n https://nodejs.org/api/net.html#class-netsocket\n\nSynonyms:\nnode_socket_client.SocketClient\nnode_socket_client SocketClient","url":"node_socket_client.html#SocketClient"},{"doc":"node_socket_client","title":"connect","content":"pub fn connect(\n  host host: String,\n  port port: Int,\n  state state: a,\n  handler handler: fn(a, SocketClient, Event(String)) -&gt; a,\n) -&gt; SocketClient\n Create a UTF-8 encoded socket connection to a given host and port.\n\nSynonyms:\nnode_socket_client.connect\nnode_socket_client connect","url":"node_socket_client.html#connect"},{"doc":"node_socket_client","title":"destroy","content":"pub fn destroy(socket: SocketClient) -&gt; Nil\n Close the socket forcefully, even if there is data in the buffer still to\n be written.\n\n If the &#39;finish&#39; event was already emitted the socket is destroyed immediately.\n If the socket is still writable it implicitly calls end().\n\nSynonyms:\nnode_socket_client.destroy\nnode_socket_client destroy","url":"node_socket_client.html#destroy"},{"doc":"node_socket_client","title":"destroy_soon","content":"pub fn destroy_soon(socket: SocketClient) -&gt; Nil\n Close the socket forcefully, once all bufferd data has been written to it.\n\n If the &#39;finish&#39; event was already emitted the socket is destroyed immediately.\n If the socket is still writable it implicitly calls end().\n\nSynonyms:\nnode_socket_client.destroy_soon\nnode_socket_client destroy_soon","url":"node_socket_client.html#destroy_soon"},{"doc":"node_socket_client","title":"end","content":"pub fn end(socket: SocketClient) -&gt; Nil\n Close the socket gracefully.\n\n This will &quot;half-close&quot; the socket. i.e., it sends a FIN packet. It is\n possible the server will still send some data.\n\nSynonyms:\nnode_socket_client.end\nnode_socket_client end","url":"node_socket_client.html#end"},{"doc":"node_socket_client","title":"write","content":"pub fn write(socket: SocketClient, data: String) -&gt; Bool\n Sends data on the socket with UTF-8 encoding.\n\n Returns true if the entire data was flushed successfully to the kernel\n buffer. Returns false if all or part of the data was queued in user memory.\n &#39;drain&#39; will be emitted when the buffer is again free.\nSynonyms:\nnode_socket_client.write\nnode_socket_client write","url":"node_socket_client.html#write"},{"doc":"node_socket_client","title":"node_socket_client","content":" Low level bindings to Node&#39;s net Socket client.\n\n &lt;https://nodejs.org/api/net.html#class-netsocket&gt;","url":"node_socket_client.html"}]);